@@ -30,6 +30,12 @@ API_GET_ATHENA_TABLES = "/ccf/services/v2.0/get_athena_tables"
 API_QUERY_ATHENA_TABLE = "/ccf/services/v2.0/query_athena_table"
 API_RUN_QUERY_ON_ATHENA = "/ccf/services/v2.0/run_query_on_athena"
 
+# Environment Variables
+_USER_NAME: str = 'USER_NAME'
+_ACCESS_TOKEN: str = 'ACCESS_TOKEN'
+_USER_ROLE: str = 'USER_ROLE'
+_CCF_SERVICES_HOST: str = 'CCF_SERVICES_HOST'
+
 HEADERS = {
     'content-type': "application/json",
     'user-agent': "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
@@ -44,40 +50,42 @@ TABLE_STYLES = [dict(selector="caption", props=[("text-align", "inline"), ("font
 ################################################################################
 # Athena Client
 ################################################################################
+def connect():
+    # TODO - Add user validation
+    try:
+        _user_name = os.getenv(_USER_NAME, None)
+        _access_token = os.getenv(_ACCESS_TOKEN, None)
+        _user_role = os.getenv(_USER_ROLE, None)
+        _ccf_services_host = os.getenv(_CCF_SERVICES_HOST, None)
+        payload = json.dumps({"user_name": _user_name, "role_id": _user_role})
+        r = requests.post(_ccf_services_host + API_VALIDATE_USER, data=payload, headers=HEADERS,
+                          cookies=dict(sessionId=_access_token))
+        response = r.json()
+        if response[STATUS] == SUCCESS:
+            athena_client = AthenaClient(user_name=_user_name, user_role=_user_role, access_token=_access_token,
+                                         ccf_services_host=_ccf_services_host)
+            return athena_client
+        else:
+            return response[ERROR]
+
+    except requests.exceptions.HTTPError:
+        raise Exception("Http error occurred") from None
+    except requests.exceptions.ConnectionError:
+        raise ConnectionError("Connection error occurred") from None
+    except requests.exceptions.Timeout:
+        raise TimeoutError("Request timed out...") from None
+    except requests.exceptions.RequestException:
+        raise Exception("RequestException occurred") from None
+
 
 class AthenaClient:
-    # Environment Variables
-    _USER_NAME: str = 'USER_NAME'
-    _ACCESS_TOKEN: str = 'ACCESS_TOKEN'
-    _USER_ROLE: str = 'USER_ROLE'
-    _CCF_SERVICES_HOST: str = 'CCF_SERVICES_HOST'
 
-    def __init__(self):
-        self._user_name = os.getenv(self._USER_NAME, None)
-        self._access_token = os.getenv(self._ACCESS_TOKEN, None)
-        self._user_role = os.getenv(self._USER_ROLE, None)
-        self._ccf_services_host = os.getenv(self._CCF_SERVICES_HOST, None)
-
-    def connect(self):
-        # TODO - Add user validation
-        try:
-            payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role})
-            r = requests.post(self._ccf_services_host + API_VALIDATE_USER, data=payload, headers=HEADERS,
-                              cookies=dict(sessionId=self._access_token))
-            response = r.json()
-            if response[STATUS] == SUCCESS:
-                return response[RESULT]
-            else:
-                return response[ERROR]
-
-        except requests.exceptions.HTTPError:
-            raise Exception("Http error occurred") from None
-        except requests.exceptions.ConnectionError:
-            raise ConnectionError("Connection error occurred") from None
-        except requests.exceptions.Timeout:
-            raise TimeoutError("Request timed out...") from None
-        except requests.exceptions.RequestException:
-            raise Exception("RequestException occurred") from None
+    def __init__(self, user_name, access_token, user_role, ccf_services_host):
+        self._user_name = user_name
+        self._access_token = access_token
+        self._user_role = user_role
+        self._ccf_services_host = ccf_services_host
+        print("Connection is successful...")
 
     def databases(self, result_as_df=True):
         """Returns all the schemas available in Athena"""
